//! Various implementations of [`crate::ShipBehavior`]

mod null;
mod point;

use std::collections::HashMap;

use galactica_gameobject::GameShipHandle;
pub use null::*;
pub use point::Point;
use rapier2d::dynamics::{RigidBodyHandle, RigidBodySet};

use crate::{
	objects::{ShipControls, ShipWorldObject},
	StepResources,
};

/// Main behavior trait. Any struct that implements this
/// may be used to control a ship.
pub trait ShipBehavior {
	/// Update a ship's controls based on world state.
	/// This method does not return anything, it modifies
	/// the ship's controls in-place.
	fn update_controls(
		&mut self,
		res: &StepResources,
		rigid_bodies: &RigidBodySet,
		ships: &HashMap<GameShipHandle, ShipWorldObject>,
		this_ship: RigidBodyHandle,
		this_data: GameShipHandle,
	) -> ShipControls;
}
